Skip to contents

County homeless estimates split into sheltered and unsheltered components (sheltered + unsheltered = total), long format. The county total is the disaggregated estimate from homeless; it is split using the shelter ratio of the county's dominant CoC (from the crosswalk county_coc2019 and pit_coc). Join to county geography by fips (e.g. counties or sp_homeless); the same sheltered/unsheltered values are also carried directly on sp_homeless as sheltered<yy> / unsheltered<yy>. Note the 2021 unsheltered values reflect HUD's COVID-19 unsheltered-count waiver.

Usage

county_pit

Format

A data frame with one row per county-year and 5 variables:

fips

5-digit county FIPS code.

year

Year.

total

Estimated total homeless.

sheltered

Estimated sheltered homeless.

unsheltered

Estimated unsheltered homeless.

HUD PIT counts disaggregated to counties; see homeless.